"""
Module Data - Immutable data structure for modules.

Company: eXonware.com
Author: Eng. Muhammad AlShehri
Email: connect@exonware.com
Version: 0.1.0.19
Generation Date: 15-Nov-2025

Re-export ModuleData from defs.py for backward compatibility.
"""

# Re-export from defs.py
from ..defs import ModuleData

__all__ = ['ModuleData']

